import { Component } from "@angular/core";
import { TableMonitoringService } from "../monitoring.service";
import { Router } from "@angular/router";
import { BuildingService } from "../../service/monitoring-api.service";
import { LoginService } from "../../service/login.service";
import { DeviceService } from "../../service/device.service";

@Component({
  selector: "app-building",
  templateUrl: "./building.component.html",
  styleUrls: ["./building.component.css"],
})
export class BuildingComponent {
  public breadcrumb: any;
  feedbacksdonutChart: any;
  donutChart1: any;
  filteredRows: any[];
  topUseData: any;
  searchTerm: string = "";
  colorChart: string = "";
  spinnerFilterActive = false;
  typeData: any;
  labelData: any;

  dataBuildingList: any;
  buildingSelected: any;
  dataFloorList: any;
  floorSelected: any;

  constructor(
    private monitoringService: TableMonitoringService,
    private monitoringApiService: BuildingService,
    private deviceService: DeviceService,
    private router: Router,
    private authService: LoginService
  ) {}

  ngOnInit() {
    this.authService.startTokenCheck();
    this.authService.startTrackingActivity();
    this.breadcrumb = {
      mainlabel: "Dashboard",
      links: [
        {
          name: "Dashboard",
          isLink: false,
        },
      ],
    };

    this.donutChart1 = {
      type: "Pie",
      options: {
        fullwidth: true,
        height: "300px",
        donut: true,
        donutWidth: 50,
        startAngle: 270,
        total: 200,
        showLabel: false,
      },
    };
    this.listBuilding(this.buildingSelected, this.floorSelected);
    this.dataListBuilding();
    this.dataListFloor();
  }

  dataListBuilding() {
    this.monitoringApiService.getBuildingList().subscribe((data) => {
      this.dataBuildingList = data.data.filter(
        (item) => item.statusName.toLowerCase() === "aktif"
      );
    });
  }

  dataListFloor() {
    this.monitoringApiService.getMasterData().subscribe((data) => {
      const dataMasterFloor = data.results.data.find(
        (item) => item.name === "master_floor"
      );
      const listFloor = dataMasterFloor.headerDetailParam.sort(
        (a, b) => b.id - a.id
      );
      const newArray = listFloor
        .map((item) => ({
          id: item.id,
          name: `${item.name} (${item.code})`,
        }))
        .sort((a, b) => b.id - a.id);

      this.dataFloorList = newArray;
    });
  }

  listBuilding(buildingId, floorId) {
    this.deviceService.filterDashboard(buildingId, floorId).subscribe((res) => {
      this.filteredRows = res.data;
      this.typeData = this.filteredRows[0].type;
      if (this.typeData === "building") {
        this.labelData = "Building";
      } else if (this.typeData === "floor") {
        this.labelData = "Floor";
      } else if (this.typeData === "room") {
        this.labelData = "Room";
      }
    });
  }

  doFilter() {
    this.spinnerFilterActive = true;
    this.listBuilding(this.buildingSelected, this.floorSelected);
    setTimeout(() => {
      this.spinnerFilterActive = false;
    }, 3000);
  }

  viewDetail(row) {
    if (row.building_id !== undefined && row.floor_id === undefined) {
      this.router.navigate(["/monitoring/view-detail-floor", row.id]);
    } else if (row.building_id !== undefined && row.floor_id !== undefined) {
      this.router.navigate(["/monitoring/view-detail-room", row.id]);
    } else {
      this.router.navigate(["/monitoring/view-detail-building", row.id]);
    }
    console.log(row.floor_id);
    console.log(row.building_id);
    
    // this.router.navigate(["/monitoring/view-detail", row.id]);
  }

  editRow(row) {
    this.router.navigate(["/monitoring/edit-new-building", row.id]);
  }

  viewRoom(row) {
    this.router.navigate(["/monitoring/monitoring-room", row.id]);
  }
}
